@@ -4,16 +4,61 @@ import re
 import shutil
 import sys
 
-from argparse import ArgumentParser, FileType, ArgumentTypeError
+from argparse import ArgumentParser, FileType, ArgumentTypeError, Action
 from collections import namedtuple
 from itertools import chain
 from toot import config, commands, CLIENT_NAME, CLIENT_WEBSITE, __version__
 from toot.exceptions import ApiError, ConsoleError
 from toot.output import print_out, print_err
 
-VISIBILITY_CHOICES = ['public', 'unlisted', 'private', 'direct']
+VISIBILITY_CHOICES = ["public", "unlisted", "private", "direct"]
 VISIBILITY_CHOICES_STR = ", ".join(f"'{v}'" for v in VISIBILITY_CHOICES)
 
+PRIVACY_CHOICES = ["public", "unlisted", "private"]
+PRIVACY_CHOICES_STR = ", ".join(f"'{v}'" for v in PRIVACY_CHOICES)
+
+
+class BooleanOptionalAction(Action):
+    """
+    Backported from argparse. This action is available since Python 3.9.
+    https://github.com/python/cpython/blob/3.11/Lib/argparse.py
+    """
+    def __init__(self,
+                 option_strings,
+                 dest,
+                 default=None,
+                 type=None,
+                 choices=None,
+                 required=False,
+                 help=None,
+                 metavar=None):
+
+        _option_strings = []
+        for option_string in option_strings:
+            _option_strings.append(option_string)
+
+            if option_string.startswith('--'):
+                option_string = '--no-' + option_string[2:]
+                _option_strings.append(option_string)
+
+        super().__init__(
+            option_strings=_option_strings,
+            dest=dest,
+            nargs=0,
+            default=default,
+            type=type,
+            choices=choices,
+            required=required,
+            help=help,
+            metavar=metavar)
+
+    def __call__(self, parser, namespace, values, option_string=None):
+        if option_string in self.option_strings:
+            setattr(namespace, self.dest, not option_string.startswith('--no-'))
+
+    def format_usage(self):
+        return ' | '.join(self.option_strings)
+
 
 def get_default_visibility():
     return os.getenv("TOOT_POST_VISIBILITY", "public")
@@ -38,6 +83,14 @@ def visibility(value):
     return value
 
 
+def privacy(value):
+    """Validates the privacy parameter"""
+    if value not in PRIVACY_CHOICES:
+        raise ValueError(f"Invalid privacy value. Expected one of {PRIVACY_CHOICES_STR}.")
+
+    return value
+
+
 def timeline_count(value):
     n = int(value)
     if not 0 < n <= 20:
@@ -253,6 +306,53 @@ AUTH_COMMANDS = [
         arguments=[],
         require_auth=False,
     ),
+    Command(
+        name="update_account",
+        description="Update your account details",
+        arguments=[
+            (["--display-name"], {
+                "type": str,
+                "help": "The display name to use for the profile.",
+            }),
+            (["--note"], {
+                "type": str,
+                "help": "The account bio.",
+            }),
+            (["--avatar"], {
+                "type": FileType("rb"),
+                "help": "Path to the avatar image to set.",
+            }),
+            (["--header"], {
+                "type": FileType("rb"),
+                "help": "Path to the header image to set.",
+            }),
+            (["--bot"], {
+                "action": BooleanOptionalAction,
+                "help": "Whether the account has a bot flag.",
+            }),
+            (["--discoverable"], {
+                "action": BooleanOptionalAction,
+                "help": "Whether the account should be shown in the profile directory.",
+            }),
+            (["--locked"], {
+                "action": BooleanOptionalAction,
+                "help": "Whether manual approval of follow requests is required.",
+            }),
+            (["--privacy"], {
+                "type": privacy,
+                "help": f"Default post privacy for authored statuses. One of: {PRIVACY_CHOICES_STR}."
+            }),
+            (["--sensitive"], {
+                "action": BooleanOptionalAction,
+                "help": "Whether to mark authored statuses as sensitive by default."
+            }),
+            (["--language"], {
+                "type": language,
+                "help": "Default language to use for authored statuses (ISO 6391)."
+            }),
+        ],
+        require_auth=True,
+    ),
 ]
 
 TUI_COMMANDS = [
