@@ -12,6 +12,7 @@ from .constants import PALETTE
 from .entities import Status
 from .overlays import ExceptionStackTrace, GotoMenu, Help, StatusSource, StatusLinks, StatusZoom
 from .overlays import StatusDeleteConfirmation, Account
+from .poll import Poll
 from .timeline import Timeline
 from .utils import parse_content_links, show_media
 
@@ -155,7 +156,7 @@ class TUI(urwid.Frame):
 
         def _default_error_callback(ex):
             self.exception = ex
-            self.footer.set_error_message("An exception occurred, press E to view")
+            self.footer.set_error_message("An exception occurred, press X to view")
 
         _error_callback = error_callback or _default_error_callback
 
@@ -200,6 +201,9 @@ class TUI(urwid.Frame):
         def _menu(timeline, status):
             self.show_context_menu(status)
 
+        def _poll(timeline, status):
+            self.show_poll(status)
+
         def _zoom(timeline, status_details):
             self.show_status_zoom(status_details)
 
@@ -214,6 +218,7 @@ class TUI(urwid.Frame):
         urwid.connect_signal(timeline, "focus", self.refresh_footer)
         urwid.connect_signal(timeline, "media", _media)
         urwid.connect_signal(timeline, "menu", _menu)
+        urwid.connect_signal(timeline, "poll", _poll)
         urwid.connect_signal(timeline, "reblog", self.async_toggle_reblog)
         urwid.connect_signal(timeline, "reply", _reply)
         urwid.connect_signal(timeline, "source", _source)
@@ -433,18 +438,25 @@ class TUI(urwid.Frame):
             lambda x, local: self.goto_public_timeline(local))
         urwid.connect_signal(menu, "bookmark_timeline",
             lambda x, local: self.goto_bookmarks())
-
+        urwid.connect_signal(menu, "notification_timeline",
+            lambda x, local: self.goto_notifications())
         urwid.connect_signal(menu, "hashtag_timeline",
             lambda x, tag, local: self.goto_tag_timeline(tag, local=local))
 
         self.open_overlay(menu, title="Go to", options=dict(
             align="center", width=("relative", 60),
-            valign="middle", height=10 + len(user_timelines),
+            valign="middle", height=11 + len(user_timelines),
         ))
 
     def show_help(self):
         self.open_overlay(Help(), title="Help")
 
+    def show_poll(self, status):
+        self.open_overlay(
+            widget=Poll(self.app, self.user, status),
+            title="Poll",
+        )
+
     def goto_home_timeline(self):
         self.timeline_generator = api.home_timeline_generator(
             self.app, self.user, limit=40)
@@ -463,6 +475,12 @@ class TUI(urwid.Frame):
         promise = self.async_load_timeline(is_initial=True, timeline_name="bookmarks")
         promise.add_done_callback(lambda *args: self.close_overlay())
 
+    def goto_notifications(self):
+        self.timeline_generator = api.notification_timeline_generator(
+            self.app, self.user, limit=40)
+        promise = self.async_load_timeline(is_initial=True, timeline_name="notifications")
+        promise.add_done_callback(lambda *args: self.close_overlay())
+
     def goto_tag_timeline(self, tag, local):
         self.timeline_generator = api.tag_timeline_generator(
             self.app, self.user, tag, local=local, limit=40)
@@ -510,8 +528,9 @@ class TUI(urwid.Frame):
 
     def show_account(self, account_id):
         account = api.whois(self.app, self.user, account_id)
+        relationship = api.get_relationship(self.app, self.user, account_id)
         self.open_overlay(
-            widget=Account(account),
+            widget=Account(self.app, self.user, account, relationship),
             title="Account",
         )
 
@@ -651,12 +670,14 @@ class TUI(urwid.Frame):
     def close_overlay(self):
         self.body = self.overlay.bottom_w
         self.overlay = None
+        if self.timeline:
+            self.timeline.refresh_status_details()
 
     # --- Keys -----------------------------------------------------------------
 
     def unhandled_input(self, key):
         # TODO: this should not be in unhandled input
-        if key in ('e', 'E'):
+        if key in ('x', 'X'):
             if self.exception:
                 self.show_exception(self.exception)
 
