@@ -7,6 +7,7 @@ from toot import __version__
 from toot.utils import format_content
 from .utils import highlight_hashtags, highlight_keys
 from .widgets import Button, EditBox, SelectableText
+from toot import api
 
 
 class StatusSource(urwid.Padding):
@@ -99,6 +100,7 @@ class GotoMenu(urwid.ListBox):
         "public_timeline",
         "hashtag_timeline",
         "bookmark_timeline",
+        "notification_timeline",
     ]
 
     def __init__(self, user_timelines):
@@ -124,6 +126,9 @@ class GotoMenu(urwid.ListBox):
         def _bookmarks(button):
             self._emit("bookmark_timeline", False)
 
+        def _notifications(button):
+            self._emit("notification_timeline", False)
+
         def _hashtag(local):
             hashtag = self.get_hashtag()
             if hashtag:
@@ -146,6 +151,7 @@ class GotoMenu(urwid.ListBox):
         yield Button("Local public timeline", on_press=_local_public)
         yield Button("Global public timeline", on_press=_global_public)
         yield Button("Bookmarks", on_press=_bookmarks)
+        yield Button("Notifications", on_press=_notifications)
         yield urwid.Divider()
         yield self.hash_edit
         yield Button("Local hashtag timeline", on_press=lambda x: _hashtag(True))
@@ -205,13 +211,41 @@ class Help(urwid.Padding):
 
 class Account(urwid.ListBox):
     """Shows account data and provides various actions"""
-    def __init__(self, account):
-        actions = list(self.generate_contents(account))
+    def __init__(self, app, user, account, relationship):
+        self.app = app
+        self.user = user
+        self.account = account
+        self.relationship = relationship
+        self.last_action = None
+        self.setup_listbox()
+
+    def setup_listbox(self):
+        actions = list(self.generate_contents(self.account, self.relationship, self.last_action))
         walker = urwid.SimpleListWalker(actions)
         super().__init__(walker)
 
-    def generate_contents(self, account):
-        yield urwid.Text([('green', f"@{account['acct']}"), (f"  {account['display_name']}")])
+    def generate_contents(self, account, relationship=None, last_action=None):
+        if self.last_action and not self.last_action.startswith("Confirm"):
+            yield Button(f"Confirm {self.last_action}", on_press=take_action, user_data=self)
+            yield Button("Cancel", on_press=cancel_action, user_data=self)
+        else:
+            if self.user.username == account["acct"]:
+                yield urwid.Text(("light gray", "This is your account"))
+            else:
+                if relationship['requested']:
+                    yield urwid.Text(("light gray", "< Follow request is pending >"))
+                else:
+                    yield Button("Unfollow" if relationship['following'] else "Follow",
+                    on_press=confirm_action, user_data=self)
+
+                yield Button("Unmute" if relationship['muting'] else "Mute",
+                    on_press=confirm_action, user_data=self)
+                yield Button("Unblock" if relationship['blocking'] else "Block",
+                    on_press=confirm_action, user_data=self)
+
+        yield urwid.Divider("─")
+        yield urwid.Divider()
+        yield urwid.Text([('green', f"@{account['acct']}"), f"  {account['display_name']}"])
 
         if account["note"]:
             yield urwid.Divider()
@@ -219,8 +253,8 @@ class Account(urwid.ListBox):
                 yield urwid.Text(highlight_hashtags(line, followed_tags=set()))
 
         yield urwid.Divider()
-        yield urwid.Text([("ID: "), ("green", f"{account['id']}")])
-        yield urwid.Text([("Since: "), ("green", f"{account['created_at'][:10]}")])
+        yield urwid.Text(["ID: ", ("green", f"{account['id']}")])
+        yield urwid.Text(["Since: ", ("green", f"{account['created_at'][:10]}")])
         yield urwid.Divider()
 
         if account["bot"]:
@@ -232,16 +266,22 @@ class Account(urwid.ListBox):
         if "suspended" in account and account["suspended"]:
             yield urwid.Text([("warning", "Suspended \N{cross mark}")])
             yield urwid.Divider()
+        if relationship["followed_by"]:
+            yield urwid.Text(("green", "Follows you \N{busts in silhouette}"))
+            yield urwid.Divider()
+        if relationship["blocked_by"]:
+            yield urwid.Text(("warning", "Blocks you \N{no entry}"))
+            yield urwid.Divider()
 
-        yield urwid.Text([("Followers: "), ("yellow", f"{account['followers_count']}")])
-        yield urwid.Text([("Following: "), ("yellow", f"{account['following_count']}")])
-        yield urwid.Text([("Statuses: "), ("yellow", f"{account['statuses_count']}")])
+        yield urwid.Text(["Followers: ", ("yellow", f"{account['followers_count']}")])
+        yield urwid.Text(["Following: ", ("yellow", f"{account['following_count']}")])
+        yield urwid.Text(["Statuses: ", ("yellow", f"{account['statuses_count']}")])
 
         if account["fields"]:
             for field in account["fields"]:
                 name = field["name"].title()
                 yield urwid.Divider()
-                yield urwid.Text([("yellow", f"{name.rstrip(':')}"), (":")])
+                yield urwid.Text([("yellow", f"{name.rstrip(':')}"), ":"])
                 for line in format_content(field["value"]):
                     yield urwid.Text(highlight_hashtags(line, followed_tags=set()))
                 if field["verified_at"]:
@@ -251,6 +291,36 @@ class Account(urwid.ListBox):
         yield link("", account["url"])
 
 
+def take_action(button: Button, self: Account):
+    action = button.get_label()
+
+    if action == "Confirm Follow":
+        self.relationship = api.follow(self.app, self.user, self.account["id"])
+    elif action == "Confirm Unfollow":
+        self.relationship = api.unfollow(self.app, self.user, self.account["id"])
+    elif action == "Confirm Mute":
+        self.relationship = api.mute(self.app, self.user, self.account["id"])
+    elif action == "Confirm Unmute":
+        self.relationship = api.unmute(self.app, self.user, self.account["id"])
+    elif action == "Confirm Block":
+        self.relationship = api.block(self.app, self.user, self.account["id"])
+    elif action == "Confirm Unblock":
+        self.relationship = api.unblock(self.app, self.user, self.account["id"])
+
+    self.last_action = None
+    self.setup_listbox()
+
+
+def confirm_action(button: Button, self: Account):
+    self.last_action = button.get_label()
+    self.setup_listbox()
+
+
+def cancel_action(button: Button, self: Account):
+    self.last_action = None
+    self.setup_listbox()
+
+
 def link(text, url):
     attr_map = {"link": "link_focused"}
     text = SelectableText([text, ("link", url)])
